#!/bin/sh
#
# source: http://download.savannah.gnu.org/releases/freetype/freetype-2.3.9.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------Set Some Variables

soft='freetype'
softversion='2.3.9'
packageversion='60.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr \
  --enable-static=no

make
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null 
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a docs ChangeLog README $dest/usr/doc/$soft-$softversion


#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

        |-----handy-ruler-----------------------------------------------------|
freetype: freetype - A Free, High-Quality, and Portable Font Engine
freetype:
freetype: FreeType 2 is a software font engine that is designed to be small,
freetype: efficient, highly customizable, and portable while capable 
freetype: producing high-quality output (glyph images). It can be used in
freetype: graphics libraries,display servers, font conversion tools,
freetype: image generation tools, text image generation tools, and many other
freetype: products as well.
freetype:
freetype:
freetype:
EODESF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5